@@ -41,3 +41,10 @@ PREVIOUS_GTIDS_LOG_EVENT = 0x23
 INTVAR_INVALID_INT_EVENT = 0x00
 INTVAR_LAST_INSERT_ID_EVENT = 0x01
 INTVAR_INSERT_ID_EVENT = 0x02
+
+# MariaDB events
+MARIADB_ANNOTATE_ROWS_EVENT = 0xa0
+MARIADB_BINLOG_CHECKPOINT_EVENT = 0xa1
+MARIADB_GTID_EVENT = 0xa2
+MARIADB_GTID_GTID_LIST_EVENT = 0xa3
+MARIADB_START_ENCRYPTION_EVENT = 0xa4
