@@ -77,6 +77,27 @@ class GtidEvent(BinLogEvent):
         return '<GtidEvent "%s">' % self.gtid
 
 
+class MariadbGtidEvent(BinLogEvent):
+    """
+    GTID change in binlog event in MariaDB
+    https://mariadb.com/kb/en/gtid_event/
+    """
+    def __init__(self, from_packet, event_size, table_map, ctl_connection, **kwargs):
+
+        super(MariadbGtidEvent, self).__init__(from_packet, event_size, table_map, ctl_connection, **kwargs)
+
+        self.server_id = self.packet.server_id
+        self.gtid_seq_no = self.packet.read_uint64()
+        self.domain_id = self.packet.read_uint32()
+        self.flags = self.packet.read_uint8()
+        self.gtid = "%d-%d-%d" % (self.domain_id, self.server_id, self.gtid_seq_no)
+
+    def _dump(self):
+        super(MariadbGtidEvent, self)._dump()
+        print("Flags:", self.flags)
+        print('GTID:', self.gtid)
+
+
 class RotateEvent(BinLogEvent):
     """Change MySQL bin log file
 
@@ -154,7 +175,7 @@ class HeartbeatLogEvent(BinLogEvent):
 
 
 class QueryEvent(BinLogEvent):
-    '''This evenement is trigger when a query is run of the database.
+    '''This event is trigger when a query is run of the database.
     Only replicated queries are logged.'''
     def __init__(self, from_packet, event_size, table_map, ctl_connection, **kwargs):
         super(QueryEvent, self).__init__(from_packet, event_size, table_map,
