@@ -5,5 +5,8 @@ from pymysqlreplication.tests.test_data_type import *
 from pymysqlreplication.tests.test_data_objects import *
 
 if __name__ == "__main__":
-    import unittest
+    if sys.version_info < (2, 7):
+        import unittest2 as unittest
+    else:
+        import unittest
     unittest.main()
